####################
Models (``models``)
####################
    
.. automodule:: nimfa.models
	:members:
	:undoc-members:
	:inherited-members:
	:show-inheritance:	


.. toctree::
   :maxdepth: 2

   nimfa.models.nmf
   
   nimfa.models.nmf_std
   
   nimfa.models.nmf_ns
   
   nimfa.models.nmf_mm
   
   nimfa.models.smf
   
   nimfa.models.mf_fit
   
   nimfa.models.mf_track
   

